# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.0.2] - 2024-03-31

### Changed

- Added metadata for python and npm packages.

## [0.0.1] - 2024-03-31

### Added

- First basic version of the widget is working.

- Correct syntax highlighting for any supported CodeMirror language, and code blocks within markdown.

- Added basic docs in README, should still be improved.
